@@ -37,6 +37,7 @@
 /// ROCWMMA_ARCH_GFX1100
 /// ROCWMMA_ARCH_GFX1101
 /// ROCWMMA_ARCH_GFX1102
+/// ROCWMMA_ARCH_GFX1150
 /// ROCWMMA_ARCH_GFX1151
 /// ROCWMMA_ARCH_GFX1200
 /// ROCWMMA_ARCH_GFX1201
@@ -64,6 +65,8 @@
 #define ROCWMMA_ARCH_GFX1101 __gfx1101__
 #elif defined(__gfx1102__) && ROCWMMA_DEVICE_COMPILE
 #define ROCWMMA_ARCH_GFX1102 __gfx1102__
+#elif defined(__gfx1150__) && ROCWMMA_DEVICE_COMPILE
+#define ROCWMMA_ARCH_GFX1150 __gfx1150__
 #elif defined(__gfx1151__) && ROCWMMA_DEVICE_COMPILE
 #define ROCWMMA_ARCH_GFX1151 __gfx1151__
 #elif defined(__gfx1200__) && ROCWMMA_DEVICE_COMPILE
@@ -97,6 +100,9 @@ static_assert(0, "Unsupported architecture");
 #if !defined(ROCWMMA_ARCH_GFX1102)
 #define ROCWMMA_ARCH_GFX1102 0
 #endif
+#if !defined(ROCWMMA_ARCH_GFX1150)
+#define ROCWMMA_ARCH_GFX1150 0
+#endif
 #if !defined(ROCWMMA_ARCH_GFX1151)
 #define ROCWMMA_ARCH_GFX1151 0
 #endif
@@ -128,7 +134,7 @@ static_assert(0, "Unsupported architecture");
 #define ROCWMMA_BLOCK_DIM_32_SUPPORTED 1
 #endif
 
-#if ROCWMMA_ARCH_GFX1100 || ROCWMMA_ARCH_GFX1101 || ROCWMMA_ARCH_GFX1102 || ROCWMMA_ARCH_GFX1151
+#if ROCWMMA_ARCH_GFX1100 || ROCWMMA_ARCH_GFX1101 || ROCWMMA_ARCH_GFX1102 || ROCWMMA_ARCH_GFX1150 || ROCWMMA_ARCH_GFX1151
 #define ROCWMMA_ARCH_GFX11 1
 #define ROCWMMA_WAVE32_MODE 1
 #define ROCWMMA_BLOCK_DIM_16_SUPPORTED 1
